@@ -31,7 +31,7 @@ class BTInterface(AbstractInterface):
     'images_st': ('ifsw_statusarea_bluetooth_online'),
     'text': ('Off', 'On', '<>'),
     'show': (False, True, True),
-    'banner': (True, False, True),
+    'banner': (True, True, True),
     'value': 0,
     'strength': 0,
     'modes': ('bluetooth-connectable', 'bluetooth-discoverable'),
