@@ -21,19 +21,22 @@ class AISLocale(Locale):
       'item-Off': 'Off',
       'item-Connected':  'Connected',
       'item-<>':  '<>',
-      'item-gsm-3g+gsm':  '3G+GSM',
-      'item-gsm-2g':  '2G',
-      'item-gsm-3g':  '3G',
-      'item-bluetooth-connectable': 'Connectable',
-      'item-bluetooth-discoverable': 'Discoverable',
-      'item-wlan-stock': 'Stock',
-      'item-wlan-bleeding-edge': 'Bleeding Edge',
+      'gsm-3g+gsm':  '3G+GSM',
+      'gsm-2g':  '2G',
+      'gsm-3g':  '3G',
+      'bluetooth-connectable': 'Connectable',
+      'bluetooth-discoverable': 'Discoverable',
+      'wlan-stock': 'Stock',
+      'wlan-bleeding-edge': 'Bleeding Edge',
       'settings/bluetooth/show-state-dialog': 'Bluetooth: dialog on click',
-      'settings/bluetooth/startup-enable': 'Bluetooth: enable on startup',
+      'settings/bluetooth/enable-on-startup': 'Bluetooth: enable on startup',
+      'settings/bluetooth/mode-on-startup': 'Bluetooth: enabled mode on startup',
       'settings/gsm/show-state-dialog': 'GSM: dialog on click',
-      'settings/gsm/startup-enable': 'GSM: enable on startup',
+      'settings/gsm/enable-on-startup': 'GSM: enable on startup',
+      'settings/gsm/mode-on-startup': 'GSM: enabled mode on startup',
       'settings/wlan/show-state-dialog': 'WLAN: dialog on click',
-      'settings/wlan/startup-enable': 'WLAN: enable on startup'
+      'settings/wlan/enable-on-startup': 'WLAN: enable on startup',
+      'settings/wlan/mode-on-startup': 'WLAN: enabled mode on startup'
     }
 
 __locale_singleton = AISLocale()
